==> musashi-core-1.0.3.tar.gz: musashi-core-1.0.3/help/ja-sjis/xtheaderHelp.h <==

#include "commonHelp.h"
/*============================================================================*/
/* R}hwv,man,musahi GUI ʃbZ[WǗ                           */
/*============================================================================*/
/*----------------------------------------------------------------------------*/
/* R}h̃^Cg                                                         */
/* R}hwv̍ŏ̍sɕ\\                                             */
/*----------------------------------------------------------------------------*/
#define HELPT "xmlTabl̃wb_[ύX"

/*----------------------------------------------------------------------------*/
/* p[^                                                                 */
/* R}hwv USAGE:Ƃ"L[[h XXXT"\\ ex)-k L[ږXg*/
/* flag̃IvV̓R}hwvOPTIONS)Ƃĕ\\ ex)-z : Wo͂̈k*/
/*----------------------------------------------------------------------------*/
/*-a*/
#define FNMT "VږXg"
#define FNMC "Ŏw肵ږXgɕύX"

/*-l*/
#define TITT "^Cg"
#define TITC "Ŏw肵^CgɕύX"

/*-c*/
#define COMT "Rg"
#define COMC "Ŏw肵RgɕύX"

/*-I*/
#define IMPT "C|[gt@C"
#define IMPC "wb_[C|[gÃwb_[ɕύX"

/*-S*/
#define SRTT "\\[g"
#define SRTC "wb_[̍ڏ̂A\\[ĝ݂B"

/*-i*/
#define INFT C_INFT
#define INFC C_INFC

/*-o*/
#define OTFT C_OTFT
#define OTFC C_OTFC

/*-z*/
#define ZIPT C_ZIPT
#define ZIPC C_ZIPC

/*----------------------------------------------------------------------------*/
/* v                                                                       */
/* R}hwvSUMMARY:Ƃĕ\\                                     */
/* HTMLwvmanɂ́AHELPD̏Ɍ`ŕ\\                   */
/*----------------------------------------------------------------------------*/
#define HELPS "wb_[(ږ,^Cg,Rg)ύXB"

/*----------------------------------------------------------------------------*/
/*                                                                          */
/*----------------------------------------------------------------------------*/
#define HELPE "\
xtheader -a ڋq,N, -i dat.xt -o rsl.xt\n\
xtheader -l ڋq}X^[ -c 2002N0101_ -i dat.xt -o rsl.xt\n\
xtheader -S -i dat.xt -o rsl.xt\n\
"

/*----------------------------------------------------------------------------*/
/* QƃR}h(KJ}ŋ؂A󔒂͗pȂ)                           */
/*----------------------------------------------------------------------------*/
#define HELPR "xtmkheader,xtmkdata"

/*----------------------------------------------------------------------------*/
/* ҂ɂ                                                               */
/* R}hwvɂ͕\\Ȃ                                             */
/*----------------------------------------------------------------------------*/
#define HELPA C_HELPA

/*----------------------------------------------------------------------------*/
/* oO|[g                                                               */
/* o^΃R}hwvBUG REPORT:ɕ\\B                  */
/* o^Ȃ(#define HELPB "")\\ȂB                           */
/*----------------------------------------------------------------------------*/
#define HELPB C_HELPB

/*----------------------------------------------------------------------------*/
/* z[y[W                                                               */
/* o^΃R}hwvINFORMATION:ɕ\\B                 */
/* o^Ȃ(#define HELPH "")\\ȂB                           */
/*----------------------------------------------------------------------------*/
#define HELPH C_HELPH

==> musashi-core-2.0.1.tar.gz: musashi-core-2.0.1/help/ja-sjis/xtheaderHelp.h <==

#include "commonHelp.h"
/*============================================================================*/
/* R}hwv,man,musahi GUI ʃbZ[WǗ                           */
/*============================================================================*/
/*----------------------------------------------------------------------------*/
/* R}h̃^Cg                                                         */
/* R}hwv̍ŏ̍sɕ\                                             */
/*----------------------------------------------------------------------------*/
#define HELPT "xmlTabl̃wb_[ύX"

/*----------------------------------------------------------------------------*/
/* p[^                                                                 */
/* R}hwv USAGE:Ƃ"L[[h XXXT"\ ex)-k L[ږXg*/
/* flag̃IvV̓R}hwvOPTIONS)Ƃĕ\ ex)-z : Wo͂̈k*/
/*----------------------------------------------------------------------------*/
/*-a*/
#define FNMT "VSږXg"
#define FNMC "Ŏw肵ږXgɕύX"

/*-f*/
#define FLDT "IɕύX鍀ږXg"
#define FLDC "Iȍږ̕ύXuږ:Vږv̌^Ŏw肷"
#define FLDF NULL

/*-l*/
#define TITT "^Cg"
#define TITC "Ŏw肵^CgɕύX"

/*-c*/
#define COMT "Rg"
#define COMC "Ŏw肵RgɕύX"

/*-I*/
#define IMPT "C|[gt@C"
#define IMPC "wb_[C|[gÃwb_[ɕύX"

/*-S*/
#define SRTT "\[g"
#define SRTC "wb_[̍ڏ̂A\[ĝ݂B"

/*-i*/
#define INFT C_INFT
#define INFC C_INFC

/*-o*/
#define OTFT C_OTFT
#define OTFC C_OTFC

/*-z*/
#define ZIPT C_ZIPT
#define ZIPC C_ZIPC

/*----------------------------------------------------------------------------*/
/* v                                                                       */
/* R}hwvSUMMARY:Ƃĕ\                                     */
/* HTMLwvmanɂ́AHELPD̏Ɍ`ŕ\                   */
/*----------------------------------------------------------------------------*/
#define HELPS "wb_[(ږ,^Cg,Rg)ύXB"

/*----------------------------------------------------------------------------*/
/*                                                                          */
/*----------------------------------------------------------------------------*/
#define HELPE "\
xtheader -a ڋq,N, -i dat.xt -o rsl.xt\n\
xtheader -l ڋq}X^[ -c 2002N0101_ -i dat.xt -o rsl.xt\n\
xtheader -S -i dat.xt -o rsl.xt\n\
xtheader -f N:t,:gender -i dat.xt -o rsl.xt\n\
"

/*----------------------------------------------------------------------------*/
/* QƃR}h(KJ}ŋ؂A󔒂͗pȂ)                           */
/*----------------------------------------------------------------------------*/
#define HELPR "xtmkheader,xtmkdata"

/*----------------------------------------------------------------------------*/
/* ҂ɂ                                                               */
/* R}hwvɂ͕\Ȃ                                             */
/*----------------------------------------------------------------------------*/
#define HELPA C_HELPA

/*----------------------------------------------------------------------------*/
/* oO|[g                                                               */
/* o^΃R}hwvBUG REPORT:ɕ\B                  */
/* o^Ȃ(#define HELPB "")\ȂB                           */
/*----------------------------------------------------------------------------*/
#define HELPB C_HELPB

/*----------------------------------------------------------------------------*/
/* z[y[W                                                               */
/* o^΃R}hwvINFORMATION:ɕ\B                 */
/* o^Ȃ(#define HELPH "")\ȂB                           */
/*----------------------------------------------------------------------------*/
#define HELPH C_HELPH
